<?php
class ControllerPaymentGateWay extends Controller
{
	public function index() 
	{
		$this->load->language('payment/gateway');
		
		$data['text_connect'] = $this->language->get('text_connect');
		$data['text_loading'] = $this->language->get('text_loading');
		$data['text_wait'] = $this->language->get('text_wait');
		
    	$data['button_confirm'] = $this->language->get('button_confirm');

		if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/payment/gateway.tpl'))
			return $this->load->view($this->config->get('config_template') . '/template/payment/gateway.tpl', $data);
		else
			return $this->load->view('default/template/payment/gateway.tpl', $data);
	}

	public function confirm() 
	{
		$this->load->model('checkout/order');
		$order_info = $this->model_checkout_order->getOrder($this->session->data['order_id']);

		$data['return'] = $this->url->link('checkout/success', '', 'SSL');
		$data['cancel_return'] = $this->url->link('checkout/payment', '', 'SSL');
		$data['back'] = $this->url->link('checkout/payment', '', 'SSL');

		$amount   = $this->currency->format($order_info['total'], $order_info['currency_code'], false, false);
		$amount = $this->currency->convert($amount, $order_info['currency_code'], "TOM")*10;

		$data['comment'] 	  = !empty($order_info['comment']) ? "توضیحات کاربر : {$order_info['comment']}" : 'توضیحاتی کاربر وارد نکرده است .';
		$json = array();
		try 
		{
			$mg = new GateWay();
			$params = array(
				'merchantCode' 	=> $this->config->get('gateway_merchant'),
				'amount' 		=> $amount,
				'callBackUrl' 	=> $this->url->link('payment/gateway/callback', '', 'SSL'),
				'invoiceNumber' => $order_info['order_id'],
				'payerEmail'	=> (strlen($order_info['email']) ? $order_info['email'] : ''),
			);
			$request = $mg->paymentRequest($params);
			if ($request['status']) {
				$json['success'] = 'http://gateway.com/payment/'.$request['paymentNumber'];
			} else {
				$json['error'] = $request['message'];
			}
		}
		catch (Exception $e) 
		{
			$json['error'] = 'مشکلی در برقراری ارتباط با درگاه وجود دارد';
		}
		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));		
	}

	public function callback()
	{
		if($this->session->data['payment_method']['code'] == 'gateway')
		{
			$this->load->language('payment/gateway');

			$this->document->setTitle($this->language->get('text_title'));
			
			$data['heading_title'] = $this->language->get('text_title');
			$data['text_results'] = $this->language->get('text_results');
			$data['results'] = "";

			$order_id = !empty($this->session->data['order_id']) ? $this->session->data['order_id'] : 0;
			
			//breadcrumbs
			$data['breadcrumbs'] = array();
			$data['breadcrumbs'][] = array(
				'text' => $this->language->get('text_home'), 
				'href' => $this->url->link('common/home', '', 'SSL')
			);
			$data['breadcrumbs'][] = array(
				'text' => $this->language->get('text_title'), 
				'href' => $this->url->link('payment/gateway/callback', '', 'SSL')
			);

			$this->load->model('checkout/order');
			$order_info = $this->model_checkout_order->getOrder($order_id);

			if($order_info) 
			{
				$gatewayStatus = isset($this->request->post['status']) ? $this->request->post['status'] : false;
				$gatewayPaymentNumber = isset($this->request->post['paymentNumber']) ? $this->request->post['paymentNumber'] : false;
				if($gatewayStatus && $gatewayPaymentNumber)
				{
					$mg = new GateWay();
					$params = array(
						'merchantCode' => $this->config->get('gateway_merchant'),
						'paymentNumber' => $gatewayPaymentNumber,
					);
					$request = $mg->paymentVerify($params);
						
					if($request['status'])
					{
						$comment = $this->language->get('text_results') . $gatewayPaymentNumber;
						$this->model_checkout_order->addOrderHistory($order_id, $this->config->get('gateway_order_status_id'), $comment, true);
						$data['error_warning'] = NULL;
						$data['results'] = $gatewayPaymentNumber;
						$data['button_continue'] = $this->language->get('button_complete');
						$data['continue'] = $this->url->link('checkout/success');
					}					
					else
					{
						$data['error_warning'] = strlen($request['message']) ? $request['message'] : 'متاسفانه مشکلی در برقراری ارتباط با درگاه پرداخت وجود دارد';
						$data['button_continue'] = $this->language->get('button_view_cart');
						$data['continue'] = $this->url->link('checkout/cart');							
					}			
				}
				else
				{
					$data['error_warning'] = 'پرداخت انجام نشده است';
					$data['button_continue'] = $this->language->get('button_view_cart');
					$data['continue'] = $this->url->link('checkout/cart');					
				}
			}
			else 
			{
				$data['error_warning'] = $this->language->get('error_order_id');
				$data['button_continue'] = $this->language->get('button_view_cart');
				$data['continue'] = $this->url->link('checkout/cart');
			}

			$data['column_left'] = $this->load->controller('common/column_left');
			$data['column_right'] = $this->load->controller('common/column_right');
			$data['content_top'] = $this->load->controller('common/content_top');
			$data['content_bottom'] = $this->load->controller('common/content_bottom');
			$data['footer'] = $this->load->controller('common/footer');
			$data['header'] = $this->load->controller('common/header');

			if (file_exists(DIR_TEMPLATE . $this->config->get('config_template') . '/template/payment/gateway_confirm.tpl'))
				$this->response->setOutput($this->load->view($this->config->get('config_template') . '/template/payment/gateway_confirm.tpl', $data));
			else
				$this->response->setOutput($this->load->view('default/template/payment/gateway_confirm.tpl', $data));
		}
	}
}

class GateWay{

	private $apiUrl = 'http://behbank.com/ws';

	private $gatewayUrl = 'http://behbank.com/payment';

	public function paymentRequest($params){
		$curl = curl_init();
		curl_setopt($curl, CURLOPT_URL, $this->apiUrl.'/payments/request.json');
		curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type' => 'application/json'));
		curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($params));
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
		$response = json_decode(curl_exec($curl));
		curl_close($curl);
		if(isset($response->status) && $response->status == 1 ){
			return array(
				'status'    		=>  true,
				'paymentNumber'     =>  $response->paymentNumber,
			);
		}else{
			return array(
				'status'    =>  false,
				'message'   =>  $response->message,
			);
		}
	}

	public function paymentVerify($params){
		$curl = curl_init();
		curl_setopt($curl, CURLOPT_URL, $this->apiUrl.'/payments/verify.json');
		curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type' => 'application/json'));
		curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode( $params ));
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
		$response = json_decode(curl_exec($curl));
		curl_close($curl);
		if(isset($response->status) && $response->status == 1){
			return array(
				'status'    =>  true,
			);
		}else{
			return array(
				'status'    =>  false,
				'message'   =>  $response->message,
			);
		}
	}

	public function getGatewayUrl(){
		return $this->gatewayUrl;
	}

}

?>